#[non_exhaustive]pub enum HelpBehaviour {
Nothing,
Strike,
Hide,
}👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to
poise for command handlingAvailable on crate features
framework and standard_framework only.Expand description
Describes the behaviour the help-command shall execute once it encounters a command which the user or command fails to meet following criteria :
- Lacking required permissions to execute the command.
- Lacking required roles to execute the command.
- The command can’t be used in the current channel (as in
DM onlyorguild only).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Nothing
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to
poise for command handlingThe command will be displayed, hence nothing will be done.
Strike
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to
poise for command handlingStrikes a command by applying ~~{command_name}~~.
Hide
👎Deprecated: The standard framework is deprecated, and will be removed in 0.13. Please migrate to
poise for command handlingDoes not list a command in the help-menu.